@@ -138,7 +138,7 @@ class EvalPool(ABC):
                 * A sequence of outcomes representing a single roll of a pool.
                     Outcomes are treated as having 1 count per appearance.
                 Most evaluators will expect a fixed number of pools.
-                The outcomes of the pools must be mutually comparable.
+                The union of the outcomes of the pools must be totally orderable.
                 Pools with `truncate_min` and pools with `truncate_max` are not
                 compatible with each other.
 
@@ -147,7 +147,7 @@ class EvalPool(ABC):
             If all pools are `PoolRoll`s, the result is a single outcome instead.
         """
 
-        # Cast non-pool arguments to `PoolBase`.
+        # Convert non-pool arguments to `PoolBase`.
         pools = [
             pool
             if isinstance(pool, icepool.PoolBase) else icepool.PoolRoll(pool)
@@ -427,6 +427,36 @@ sum_pool = SumPool()
 """A shared `SumPool` object for caching results. """
 
 
+class EnumeratePool(EvalPool):
+    """A `EvalPool` that enumerates all possible (sorted) rolls of a single pool.
+
+    This is expensive and not recommended unless few dice are being kept.
+    """
+
+    def __init__(self, direction=1):
+        """`direction` determines the sort order.
+
+        Positive for ascending and negative for descending.
+        """
+        self._direction = direction
+
+    def next_state(self, state, outcome, count):
+        if state is None:
+            return (outcome,) * count
+        else:
+            return state + (outcome,) * count
+
+    def direction(self, pool):
+        if any(x < 0 for x in pool.count_dice()):
+            raise ValueError(
+                'EnumeratePool is not compatible with negative counts.')
+        return self._direction
+
+
+enumerate_pool = EnumeratePool()
+"""A shared `EnumeratePool` object for caching results. """
+
+
 class FindBestSet(EvalPool):
     """A `EvalPool` that takes the best matching set in a pool.
 
